==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/kernel/time-service/type/database/src/test/java/org/apache/shardingsphere/timeservice/type/database/provider/dialect/OracleTimestampLoadingSQLProviderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.timeservice.type.database.provider.dialect;

import org.apache.shardingsphere.infra.database.core.type.DatabaseType;
import org.apache.shardingsphere.infra.spi.type.typed.TypedSPILoader;
import org.apache.shardingsphere.timeservice.type.database.provider.TimestampLoadingSQLProvider;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class OracleTimestampLoadingSQLProviderTest {
    
    private TimestampLoadingSQLProvider provider;
    
    @BeforeEach
    void setUp() {
        provider = TypedSPILoader.getService(TimestampLoadingSQLProvider.class, TypedSPILoader.getService(DatabaseType.class, "Oracle"));
    }
    
    @Test
    void assertGetTimestampLoadingSQL() {
        assertThat(provider.getTimestampLoadingSQL(), is("SELECT sysdate FROM DUAL"));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/kernel/time-service/type/database/src/test/java/org/apache/shardingsphere/timeservice/type/database/provider/dialect/OracleTimestampLoadingSQLProviderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.timeservice.type.database.provider.dialect;

import org.apache.shardingsphere.database.connector.core.type.DatabaseType;
import org.apache.shardingsphere.infra.spi.type.typed.TypedSPILoader;
import org.apache.shardingsphere.timeservice.type.database.provider.TimestampLoadingSQLProvider;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class OracleTimestampLoadingSQLProviderTest {
    
    private TimestampLoadingSQLProvider provider;
    
    @BeforeEach
    void setUp() {
        provider = TypedSPILoader.getService(TimestampLoadingSQLProvider.class, TypedSPILoader.getService(DatabaseType.class, "Oracle"));
    }
    
    @Test
    void assertGetTimestampLoadingSQL() {
        assertThat(provider.getTimestampLoadingSQL(), is("SELECT sysdate FROM DUAL"));
    }
}
